supa_helper library

Classes

AdminUserAttributes
AMREntry
An authentication method reference (AMR) entry.
ApiVersions
AuthClientOptions
AuthMFAAdminDeleteFactorResponse
AuthMFAAdminListFactorsResponse
AuthMFAChallengeResponse
AuthMFAEnrollResponse
AuthMFAGetAuthenticatorAssuranceLevelResponse
AuthMFAListFactorsResponse
AuthMFAUnenrollResponse
AuthMFAVerifyResponse
AuthOptions
AuthResponse
Response which might or might not contain session and/or user
AuthSessionUrlResponse
AuthState
AuthUser
Binding
Bucket
BucketOptions
public The visibility of the bucket. Public buckets don't require an authorization token to download objects, but still require a valid token for all other operations. By default, buckets are private.
ByteStream
A stream of chunks of bytes representing a single piece of data.
CreateOAuthClientParams
Parameters for creating a new OAuth client. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
DecodedJwt
Decoded JWT structure
EmptyLocalStorage
A LocalStorage implementation that does nothing. Use this to disable persistence.
Factor
FileObject
FileObjectV2
FileOptions
FunctionResponse
FunctionsClient
FunctionsClientOptions
GenerateLinkProperties
GenerateLinkResponse
GetClaimsOptions
Options for getClaims method
GetClaimsResponse
Response from getClaims method
GoTrueAdminApi
GoTrueAdminPasskeyApi
Admin methods for managing the passkeys of users.
GotrueAsyncStorage
Interface to provide async storage to store pkce tokens.
GoTrueClient
API client to interact with gotrue server.
GoTrueMFAApi
GoTruePasskeyApi
API namespace for passkey (WebAuthn) authentication.
JWK
JSON Web Key (JWK) representation.
JWKSet
JwtHeader
JWT Header structure
JwtPayload
JWT Payload structure with standard claims
JwtRawParts
Raw encoded parts of a JWT
LocalStorage
LocalStorage is used to persist the user session in the device.
MultipartFile
A file to be uploaded as part of a MultipartRequest.
OAuthClient
OAuth client object returned from the OAuth 2.1 server. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthProvider
An OAuth provider identifier.
OAuthResponse
Response of OAuth signin
Passkey
A passkey (WebAuthn credential) registered to a user.
PasskeyAuthenticationOptionsResponse
Response containing the options needed to sign in with a passkey.
PasskeyRegistrationOptionsResponse
Response containing the options needed to register a new passkey.
PhoneEnrollment
PostgresChangeFilter
Creates a filter for realtime postgres change listener.
PostgresChangePayload
Data class that contains the Postgres change event payload.
PostgresColumn
PostgrestBuilder<T, S, R>
The base builder class.
PostgrestClient
A PostgREST api client written in Dartlang. The goal of this library is to make an "ORM-like" restful interface.
PostgrestFilterBuilder<T>
PostgrestOptions
PostgrestQueryBuilder<T>
The query builder class provides a convenient interface to creating request queries.
PostgrestResponse<T>
A Postgrest response
PostgrestRpcBuilder
PostgrestTransformBuilder<T>
Presence
A single shared state between users with Realtime Presence.
PresenceEvents
PresenceOpts
RawPostgrestBuilder<T, S, R>
Needed as a wrapper around PostgrestBuilder to allow for the different return type of withConverter than in ResponsePostgrestBuilder.withConverter.
RealtimeChannel
RealtimeChannelConfig
RealtimeClient
Manages a persistent WebSocket connection to the Supabase Realtime server.
RealtimeCloseEvent
Event details for when the connection closed.
RealtimeOptions
RealtimePresence
RealtimePresenceJoinPayload
Payload for PresenceEvent.join callback.
RealtimePresenceLeavePayload
Payload for PresenceEvent.leave callback.
RealtimePresencePayload
Base class for the payload in .onPresence() callback functions.
RealtimePresenceSyncPayload
Payload for PresenceEvent.sync callback.
RemoveSubscriptionResult
ReplayOption
Configuration for broadcast replay feature. Allows replaying broadcast messages from a specific timestamp.
ResendResponse
ResponsePostgrestBuilder<T, S, R>
Needed as a wrapper around PostgrestBuilder to allow for the different return type of withConverter than in RawPostgrestBuilder.withConverter.
RetryOption
SearchOptions
Session
SharedPreferencesGotrueAsyncStorage
local storage to store pkce flow code verifier.
SharedPreferencesLocalStorage
A LocalStorage implementation that implements SharedPreferences as the storage method.
SignedUploadURLResponse
SignedUrl
SignedUrlFailure
A failed SignedUrlResult: the path could not be signed (e.g. the file does not exist).
SignedUrlResult
Represents a per-item result from StorageFileApi.createSignedUrlsResult.
SignedUrlSuccess
A successful SignedUrlResult: the file was found and a signed URL was generated.
SinglePresenceState
A single client connected through presence.
SocialAuthResult
this is result model of login specialy for social media providers this model is used to return id token and raw data from social media providers
SortBy
StorageFileApi
StorageOptions
StorageRetryController
Supabase
Supabase instance.
SupabaseAuth
Handles all authentication operations with Supabase.
SupabaseClient
Creates a Supabase client to interact with your Supabase instance.
SupabaseQueryBuilder
SupabaseQuerySchema
Used to perform rpc and from operations with a different schema than in SupabaseClient.
SupabaseStorageClient
SupabaseStreamBuilder
SupabaseStreamFilterBuilder
SupaDatabase
A unified interface for all Supabase database operations.
SupaHelper
SupaPage<T>
SupaRealTime
SupaSocialMediaAuth
to Add new Social Media Provider implement SupaSocialMediaAuth
SupaStorage
TOTPEnrollment
TransformOptions
Specifies the dimensions and the resize mode of the requesting image.
UpdateOAuthClientParams
Parameters for updating an existing OAuth client. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
User
UserAttributes
UserIdentity
UserResponse
Response that contains a user

Enums

AMRMethod
AuthChangeEvent
AuthenticatorAssuranceLevels
AuthFlowType
ChannelResponse
CountOption
Returns count as part of the response when specified.
FactorStatus
FactorType
GenerateLinkType
HttpMethod
LaunchMode
The desired mode to launch a URL.
OAuthClientGrantType
OAuth client grant types supported by the OAuth 2.1 server. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthClientRegistrationType
OAuth client registration type. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthClientResponseType
OAuth client response types supported by the OAuth 2.1 server. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthClientType
OAuth client type indicating whether the client can keep credentials confidential. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OtpChannel
Messaging channel to use (e.g. whatsapp or sms)
OtpType
PostgresChangeEvent
PostgresChangeFilterType
Specifies the type of filter to be applied on realtime Postgres Change listener.
PostgresTypes
PresenceEvent
RealtimeLogLevel
RealtimeProtocolVersion
RealtimeSubscribeStatus
RequestImageFormat
ResizeMode
Specifies how image cropping should be handled when performing image transformations.
ReturningOption
Returns count as part of the response when specified.
SignOutScope
Determines which sessions should be logged out.
SocketStates
SupabaseEventTypes
TextSearchType
The type of tsquery conversion to use on query.

Extensions

GoTrueClientPasskey on GoTrueClient
Passkey (WebAuthn) convenience methods that perform the full ceremony, including the platform prompt (FaceID/TouchID/security key), on top of the server side exposed by GoTrueClient.passkey.
GoTrueClientSignInProvider on GoTrueClient
PresenceEventExtended on PresenceEvent
SupabaseEventTypesName on SupabaseEventTypes

Constants

supabasePersistSessionKey → const String
Only used for migration from Hive to SharedPreferences. Not actually in use.

Functions

convertCell(String type, dynamic value) → dynamic
If the value of the cell is null, returns null. Otherwise converts the string value to the correct type.
convertChangeData(List<Map<String, dynamic>> columns, Map<String, dynamic> record, {List<String>? skipTypes}) Map<String, dynamic>
Takes an array of columns and an object of string values then converts each string value to its mapped type.
convertColumn(String columnName, List<PostgresColumn> columns, Map<String, dynamic> record, List<String> skipTypes) → dynamic
Converts the value of an individual column.
decodeJwt(String token) DecodedJwt
Decodes a JWT token without performing validation
httpEndpointURL(String socketUrl) String
Converts a WebSocket URL to an HTTP URL.
noop(dynamic value) → dynamic
toArray(dynamic value, String type) → dynamic
Converts a Postgres Array into a native Dart array
toBoolean(dynamic value) bool?
toDouble(dynamic value) double?
toInt(dynamic value) int?
toJson(dynamic value) → dynamic
toTimestampString(String? value) String?
Fixes timestamp to be ISO-8601. Swaps the space between the date and time for a 'T' See https://github.com/supabase/supabase/issues/18
validateExp(int? exp) → void
Validates the expiration time of a JWT

Typedefs

BindingCallback = void Function(dynamic payload, [dynamic ref])
BroadcastChannel = ({void Function() close, Stream<Map<String, dynamic>> onMessage, void Function(Map) postMessage})
Headers = Map<String, String>
PostgrestConverter<S, T> = S Function(T data)
PostgrestList = List<PostgrestMap>
PostgrestListResponse = PostgrestResponse<PostgrestList>
PostgrestMap = Map<String, dynamic>
PostgrestMapResponse = PostgrestResponse<PostgrestMap>
PresenceChooser<T> = T Function(String key, dynamic presence)
PresenceOnJoinCallback = void Function(String? key, dynamic currentPresences, dynamic newPresences)
PresenceOnLeaveCallback = void Function(String? key, dynamic currentPresences, dynamic newPresences)
RealtimeConstants = Constants
RealtimeDecode = Map<String, dynamic> Function(Object payload)
Deserializes a raw incoming WebSocket frame (String or binary) into a message map.
RealtimeEncode = Object Function(Map<String, dynamic> payload)
Serializes an outgoing message into the String or binary frame written to the WebSocket.
SupabaseStreamEvent = List<Map<String, dynamic>>
WebSocketTransport = WebSocketChannel Function(String url, Map<String, String> headers)

Exceptions / Errors

AuthApiException
AuthInvalidJwtException
AuthPKCEGrantCodeExchangeError
AuthRetryableFetchException
AuthSessionMissingException
AuthUnknownException
AuthWeakPasswordException
FunctionException
RealtimeSubscribeException
SupaAuthException
Thrown when an authentication operation fails.
SupabaseRealtimeError
SupaDatabaseException
Thrown when a database operation fails.
SupaException
Base exception for all supa_helper errors.
SupaRealtimeException
Thrown when a realtime subscription operation fails.
SupaStorageException
Thrown when a storage operation fails.
SupaUnExpectedException