DecodedJwt class
Decoded JWT structure
Constructors
-
DecodedJwt({required JwtHeader header, required JwtPayload payload, required List<
int> signature, required JwtRawParts raw})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → JwtHeader
-
JWT header
final
- payload → JwtPayload
-
JWT payload
final
- raw → JwtRawParts
-
Raw encoded parts of the JWT
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signature
→ List<
int> -
JWT signature as raw bytes
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited