rpc<T> method
Performs a stored procedure call.
fn is the name of the function to call.
params is an optional object to pass as arguments to the function call.
When get is set to true, the function will be called with read-only
access mode.
Implementation
PostgrestFilterBuilder<T> rpc<T>(
String fn, {
Map<String, dynamic>? params,
bool get = false,
}) {
_rest.headers.addAll({..._rest.headers, ..._headers});
return _rest.rpc(
fn,
params: params,
get: get,
);
}